<img src="https://cdn.door43.org/assets/uw-icons/logo-ult-256.png" alt="drawing" width="100"/>

# unfoldingWord® Literal Text—English

*an unrestricted literal version of the Bible intended for translation into any language as a tool for use by Bible translators*

## Overview

The ULT began as an open-licensed adaptation of *The American Standard Version*. It has since undergone a careful comparison to the original biblical languages, using the best tools that are available to modern scholarship, and made to reflect the forms of those languages as far as English grammar and understanding will allow. The ULT is thus intended to provide a ‘form-centric’ rendering of the biblical text from the original biblical languages (Biblical Hebrew, Biblical Aramaic, and Koiné Greek) into English. This increases a translator’s understanding of the lexical and grammatical composition of the biblical text by adhering closely to the grammatical (i.e. parts of speech) and syntactic (i.e. word order) stuctures of the original languages. For translators who do not speak English, we intend to translate the ULT into the other major languages of the world.

## Viewing

To read or print the ULT, see the [ULT project on Door43](https://door43.org/u/unfoldingWord/en_ult/).

## Contributors

If you are a contributor to this project please add your name to the `contributor`
field in the [manifest.yaml](https://git.door43.org/unfoldingWord/en_ult/src/master/manifest.yaml)
file.

## Introducing the ULT

The ULT (unfoldingWord® Literal Text) is a form-centric (and thus “literal”) version of the Bible in English. It is intended to be used alongside the UST (unfoldingWord® Simplified Text) and other translation resources to give English-speaking mother-tongue translators (MTTs) a more complete understanding of the messages communicated in the Bible. The purpose of the ULT text is to allow a Bible translator who does not have reading knowledge of the original biblical languages (Hebrew, Aramaic, Greek) to “see” the grammatical forms of those languages. Therefore, the goal of the ULT text as a translation resource is to copy the Original Language (OrigL) form as much as possible yet still be understandable in English or other Gateway Language (GL). For MTTs who cannot read the OrigL text, the ULT provides a sense of *how* these messages of the Bible were communicated in the OrigL. It is anticipated that the ULT and other resources will be translated from English into the world’s GLs so that MTTs worldwide can use them as a set of resources for making accurate translations of the Bible into their own languages.

The ULT stands in the range of literalness somewhere between a very literally translated user Bible (such as the New American Standard Bible [NASB]) and an English interlinear text. An English interlinear text is designed to render OrigL words into their individual and basic (“literal”) English meanings without regard to understandability of the overall English text. On the other hand, a very literally translated user Bible tries to adhere as closely as possible to the OrigL but must sometimes compromise in favor of English idiom and expression in order for the text to be both grammatically correct and readily understood. The ULT negotiates a path between these two kinds of texts. For example, the ULT reproduces the OrigL idioms even when they are not English idioms, relying on a translation note to explain the meaning. In that way, the translator can see the original expression, and also the meaning. The ULT does not substitute English idioms or expressions. However, if an OrigL grammatical form would give the wrong meaning or no meaning at all, the ULT will use the English form in that case so that the ULT can also meet the demand of reasonable understandability in English.

## Editing or Translating the ULT

The unfoldingWord® Literal Text (ULT) is designed to be used as a tool for Bible translation in conjunction with the [unfoldingWord® Simplified Text (UST)](https://git.door43.org/unfoldingWord/en_ust), the [unfoldingWord® Translation Words (UTW)](https://git.door43.org/unfoldingWord/en_tw), and the [unfoldingWord® Translation Notes (UTN)](https://git.door43.org/unfoldingWord/en_tn). It is not an end-user Bible, which seeks to transform all of the structures of the original biblical languages into those that are natural and idiomatic in the target language. Instead, unlike the UST and unlike an end-user Bible, the ULT is designed to reflect the forms of the source languages, so that the MTT can see what they are. By using the ULT, the MTT can “look through” it to see how the original Bible expressed the biblical ideas.

### Retain Original Forms and Structures

Therefore, as you (an editor or translator of the ULT) edit or translate the ULT, you must retain the grammatical and syntactic structures of the original as much as the target language (English or other Gateway Language) will reasonably allow. If the original structure is ungrammatical in the target language, then you will need to change it into a structure that is grammatical in the target language. It does no good to make a translation that a MTT using this tool cannot understand. But as much as the target language will allow, retain the structures of the original while editing or translating the ULT. For English, it is often possible to retain nouns as nouns, verbs as verbs, etc., but their order in the original sentence must be changed.

In addition to the grammatical forms, the ULT must also retain the idioms and the figures of speech found in the original languages so that the MTT can consider them and use them if they communicate the right thing in his target language (i.e. a minority or Other Language [OL], not Gateway Language). If these aspects of the original language text are changed in the English version (or other Gateway Language translation) of the ULT, then the OL translator will never see them. Furthermore, their accompanying explanations (found in the unfoldingWord® Translation Notes) will not make sense.

The ULT and the UST are designed to be complementary tools for use by an OL translator. These tools should be as useful as possible, which means that the ULT should retain original language structures that would not always be retained in an end-user Bible. Therefore, you must understand that the ULT will often lack naturalness (and sometimes also lack clarity) because it aims to reproduce the original language structures and figures of speech that the GL may not normally use. However, in places where the ULT lacks clarity, there will be BOTH a Translation Note to explain the meaning of the structure for the OL translator AND a clear rendering of the original meaning in the UST. Together, the UTN and the UST will provide the meaning of the text wherever that meaning is in doubt in the ULT. In this way, the various tools work together to provide an OL translator with more complete information about both the form and the meaning of the biblical text as written in the original languages.

One specific way in which the ULT and UST are complementary tools concerns the selection of meaning in the original language texts. There are many instances in the biblical text where the meaning of a word or phrase in the original languages is ambiguous. In those cases, the ULT should retain the ambiguity of meaning, if possible. In contrast, the UST should select the most probable meaning and express that meaning according to its own translation method. NOTE: It is acceptable for the ULT to select meaning in cases where the meaning of the original language is linguistically ambiguous but seems clear from the context.

### Examples

For examples see the [Examples](https://gl-manual.readthedocs.io/en/latest/gl_translation.html#examples) portion of the Gateway Language Manual.


### The ULT Contrasted with the UST

See the [The ULT Contrasted with the UST](https://gl-manual.readthedocs.io/en/latest/gl_translation.html#the-ult-contrasted-with-the-ust) in the Gateway Language Manual.

## Editing the ULT

See [Specific Editing Guidelines for the ULT](https://gl-manual.readthedocs.io/en/latest/gl_guidelines.html#specific-editing-guidelines-for-the-ult) in the Gateway Language Manual.


## Translating the ULT from the Original Language (OrigL)

### Translation of Terms Regarding Gender

Both Biblical Hebrew and Koiné Greek utilize different word forms to indicate grammatical gender, which may or may not correspond either to the actual gender of a person or to the lack of gender in an object. For example, the Hebrew phrase *beney yisrael* (“sons of Israel”) sometimes literally means “male children of the man named Israel” (Gen 42:5). However, most of the time in the Old Testament this phrase refers figuratively to the entire Israelite nation as a whole, both men and women. In a similar way, the Greek term *adelphoi* (“brothers”) can sometimes literally mean “a male person who has the same father and/or mother” (Mark 3:22), but most of the time in the New Testament refers figuratively to Christian believers, both men and women. This linguistic feature of “engendered language” poses significant problems for translation. The meaning of the original Hebrew/Aramaic/Greek text is not always clear; also, some languages do not use engendered language, which makes the translation of gender very difficult.

The ULT should retain the engendered language of Hebrew/Aramaic/Greek terms as much as possible. However, a notable exception to this rule concerns the translation of masculine participles (that is, verbal nouns and/or verbal adjectives) which actually refer to both men and women together; those terms can be translated without specifying gender.

### Translation Glossary for the ULT

See the [Combined ULT-UST Translation Glossary](https://gl-manual.readthedocs.io/en/latest/gl_guidelines.html#combined-ult-ust-translation-glossary) in the Gateway Language Manual.


### Translation Glossary for the Old Testament

See the [Translation Glossary for the Old Testament](https://gl-manual.readthedocs.io/en/latest/gl_guidelines.html#translation-glossary-for-the-old-testament) in the Gateway Language Manual.


### Translation Glossary for the New Testament

See the [Translation Glossary for the New Testament](https://gl-manual.readthedocs.io/en/latest/gl_guidelines.html#translation-glossary-for-the-new-testament) in the Gateway Language Manual.


### Notes About Making a “Literal” Translation

See the [Notes About Making a “Literal” Translation](https://gl-manual.readthedocs.io/en/latest/gl_translation.html?highlight=literal%20translation#notes-about-making-a-literal-translation) section in the Gateway Language Manual.


## Aligning the ULT

For information on how to align the ULT see [Aligning the ULT](https://gl-manual.readthedocs.io/en/latest/gl_guidelines.html#aligning-the-ult) in the Gateway Language Manual.
